@@ -32,6 +32,7 @@
 #include <bonobo/bonobo-object.h>
 #include <glib/gthread.h>
 #include <gnome-speech/gnome-speech.h>
+#include <eci.h>
 #include "viavoicespeaker.h"
 
 #define VIAVOICE_SYNTHESIS_DRIVER_TYPE        (viavoice_synthesis_driver_get_type ())
@@ -87,5 +88,15 @@ gboolean
 viavoice_synthesis_driver_set_voice (const ViavoiceSynthesisDriver *d,
 				     gint v);
 
+enum ECILanguageDialect 
+viavoice_synthesis_driver_language_to_dialect(char *lang);
+
+// Warning: the length of the voice name is 
+// ECI_VOICE_NAME_LENGTH + 1 
+// bytes long in unibyte character sets.
+//
+// Using some Chinese voices for example, the length can be _longer_ 
+// (charset = UCS-2).
+enum { MAX_VOICE_LENGTH = 2*(ECI_VOICE_NAME_LENGTH + 1)};
 					   
 #endif /* __VIAVOICE_SYNTHESIS_DRIVER_H_ */
